@@ -53,7 +53,7 @@ class Scene_blender(Scene, Slots_blender):
 	def rename(self, frm, to, objects=[], regEx=False, ignoreCase=False):
 		'''Rename scene objects.
 
-		:Parameters:
+		Parameters:
 			frm (str): Current name. An asterisk denotes startswith*, *endswith, *contains*, and multiple search strings can be separated by pipe ('|') chars.
 				frm - Search exact.
 				*frm* - Search contains chars.
@@ -98,12 +98,12 @@ class Scene_blender(Scene, Slots_blender):
 	def setCase(self, objects=[], case='caplitalize'):
 		'''Rename objects following the given case.
 
-		:Parameters:
+		Parameters:
 			objects (str)(list): The objects to rename. default:all scene objects
 			case (str): Desired case using python case operators. 
 				valid: 'upper', 'lower', 'caplitalize', 'swapcase' 'title'. default:'caplitalize'
 
-		:Example: setCase(pm.ls(sl=1), 'upper')
+		Example: setCase(pm.ls(sl=1), 'upper')
 		'''
 		# pm.undoInfo(openChunk=1)
 		for obj in pm.ls(objects):
