@@ -126,7 +126,7 @@ class Transform_blender(Transform, Slots_blender):
 		cmb = self.sb.transform.cmb001
 		chk = cmb.menu_.chk026
 
-		selection = pm.ls(sl=1, objectsOnly=1)
+		selection = pm.ls(sl=1, objectsOnly=1, type='transform')
 		if state and selection:
 			live_object = pm.ls(live=1)
 			shape = self.getShapeNode(selection[0])
@@ -337,7 +337,7 @@ class Transform_blender(Transform, Slots_blender):
 		'''Make Live (Toggle)
 		'''
 		cmb = self.sb.transform.cmb001
-		selection = pm.ls(sl=1, objectsOnly=1)
+		selection = pm.ls(sl=1, objectsOnly=1, type='transform')
 
 		if selection:
 			live_object = pm.ls(live=1)
@@ -967,7 +967,7 @@ print (__name__)
 			
 	# 		elif text=='Make Live'):
 	# 			print ('3')
-	# 			selection = pm.ls(sl=1, objectsOnly=1)
+	# 			selection = pm.ls(sl=1, objectsOnly=1, type='transform')
 	# 			if not selection and not live_object:
 	# 				print ('not selection and not live_object')
 	# 				cmb.setCurrentIndex(0)
