@@ -51,12 +51,12 @@ class Animation_max(Animation, Slots_max):
 	def getSubAnimControllers(self, node, keyable=False, _result=[]):
 		'''Returns a list of all the subanim controllers for a given node.
 
-		:Parameters:
+		Parameters:
 			node (obj): The node in which to query controllers of.
 			keyable (bool): Return only keyable controllers.
 			_result (obj): Recursive call.
 
-		:Return:
+		Return:
 			(list) A List of sub level animation controllers.
 
 		ex. ctrls = getSubAnimControllers(obj)
@@ -78,10 +78,10 @@ class Animation_max(Animation, Slots_max):
 		'''Filters a given list for controllers that are keyable.
 		You can get the initial list of controllers using getSubAnimControllers.
 
-		:Parameters:
+		Parameters:
 			controllers (list): A list of controller objects.
 
-		:Return:
+		Return:
 			(list) A list of keyable controllers.
 
 		ex. ctrls = getSubAnimControllers(obj)
@@ -101,7 +101,7 @@ class Animation_max(Animation, Slots_max):
 	def AssignController(self, currentController, newController):
 		'''Attempts at assigning a given controller.
 
-		:Parameters:
+		Parameters:
 			currentController (obj): 
 			newController (obj): 
 
@@ -127,13 +127,13 @@ class Animation_max(Animation, Slots_max):
 	def setCurrentFrame(self, frame=1, relative=False, update=True):
 		'''Set the current frame on the timeslider.
 
-		:Parameters:
+		Parameters:
 		frame (int): Desired from number.
 		relative (bool): If True; the frame will be moved relative to 
 			it's current position using the frame value as a move amount.
 		update (bool): Change the current time, but do not update the world. (default=True)
 
-		:Example:
+		Example:
 			setCurrentFrame(24, relative=True, update=1)
 		'''
 		currentTime=0
@@ -147,11 +147,11 @@ class Animation_max(Animation, Slots_max):
 	def invertSelectedKeyframes(self, time=1, relative=True):
 		'''Duplicate any selected keyframes and paste them inverted at the given time.
 
-		:Parameters:
+		Parameters:
 			time (int): The desired start time for the inverted keys.
 			relative (bool): Start time position as relative or absolute.
 
-		:Example: invertSelectedKeyframes(time=48, relative=0)
+		Example: invertSelectedKeyframes(time=48, relative=0)
 		'''
 		allActiveKeyTimes = pm.keyframe(query=True, sl=True, tc=True) #get times from all selected keys.
 		if not allActiveKeyTimes:
